==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_results/mp6521_001/MP6521_DeleteUserSetupResponsibility_001_Result.java <==

package net.datastream.schemas.mp_results.mp6521_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERSETUPRESPONSIBILITYID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}USERSETUPRESPONSIBILITYID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP6521_DeleteUserSetupResponsibility_001_Result")
public class MP6521_DeleteUserSetupResponsibility_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP6521_DeleteUserSetupResponsibility_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP6521_DeleteUserSetupResponsibility_001_Result.ResultData }
     *     
     */
    public MP6521_DeleteUserSetupResponsibility_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP6521_DeleteUserSetupResponsibility_001_Result.ResultData }
     *     
     */
    public void setResultData(MP6521_DeleteUserSetupResponsibility_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERSETUPRESPONSIBILITYID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "usersetupresponsibilityid"
    })
    public static class ResultData {

        @XmlElement(name = "USERSETUPRESPONSIBILITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected USERSETUPRESPONSIBILITYID_Type usersetupresponsibilityid;

        /**
         * Obtient la valeur de la propriété usersetupresponsibilityid.
         * 
         * @return
         *     possible object is
         *     {@link USERSETUPRESPONSIBILITYID_Type }
         *     
         */
        public USERSETUPRESPONSIBILITYID_Type getUSERSETUPRESPONSIBILITYID() {
            return usersetupresponsibilityid;
        }

        /**
         * Définit la valeur de la propriété usersetupresponsibilityid.
         * 
         * @param value
         *     allowed object is
         *     {@link USERSETUPRESPONSIBILITYID_Type }
         *     
         */
        public void setUSERSETUPRESPONSIBILITYID(USERSETUPRESPONSIBILITYID_Type value) {
            this.usersetupresponsibilityid = value;
        }

    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_results/mp6521_001/MP6521_DeleteUserSetupResponsibility_001_Result.java <==

package net.datastream.schemas.mp_results.mp6521_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERSETUPRESPONSIBILITYID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}USERSETUPRESPONSIBILITYID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP6521_DeleteUserSetupResponsibility_001_Result")
public class MP6521_DeleteUserSetupResponsibility_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP6521_DeleteUserSetupResponsibility_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP6521_DeleteUserSetupResponsibility_001_Result.ResultData }
     *     
     */
    public MP6521_DeleteUserSetupResponsibility_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP6521_DeleteUserSetupResponsibility_001_Result.ResultData }
     *     
     */
    public void setResultData(MP6521_DeleteUserSetupResponsibility_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERSETUPRESPONSIBILITYID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "usersetupresponsibilityid"
    })
    public static class ResultData {

        @XmlElement(name = "USERSETUPRESPONSIBILITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected USERSETUPRESPONSIBILITYID_Type usersetupresponsibilityid;

        /**
         * Gets the value of the usersetupresponsibilityid property.
         * 
         * @return
         *     possible object is
         *     {@link USERSETUPRESPONSIBILITYID_Type }
         *     
         */
        public USERSETUPRESPONSIBILITYID_Type getUSERSETUPRESPONSIBILITYID() {
            return usersetupresponsibilityid;
        }

        /**
         * Sets the value of the usersetupresponsibilityid property.
         * 
         * @param value
         *     allowed object is
         *     {@link USERSETUPRESPONSIBILITYID_Type }
         *     
         */
        public void setUSERSETUPRESPONSIBILITYID(USERSETUPRESPONSIBILITYID_Type value) {
            this.usersetupresponsibilityid = value;
        }

    }

}
